Internal APIs
=============

These packages are for internal use in communicating with the low-level
API.  You should use the object oriented API instead.  They are documented
here for developer reference.


juju\.client\.client module
---------------------------

.. automodule:: juju.client.client
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\._definitions module
---------------------------------

.. automodule:: juju.client._definitions
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\._client module
----------------------------

.. automodule:: juju.client._client
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\._client1 module
-----------------------------

.. automodule:: juju.client._client1
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\._client2 module
-----------------------------

.. automodule:: juju.client._client2
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\._client3 module
-----------------------------

.. automodule:: juju.client._client3
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\._client4 module
-----------------------------

.. automodule:: juju.client._client4
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\._client5 module
-----------------------------

.. automodule:: juju.client._client5
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\.codegen module
----------------------------

.. automodule:: juju.client.codegen
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\.connection module
-------------------------------

.. automodule:: juju.client.connection
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\.facade module
---------------------------

.. automodule:: juju.client.facade
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\.overrides module
------------------------------

.. automodule:: juju.client.overrides
    :members:
    :undoc-members:
    :show-inheritance:

juju\.client\.runner module
---------------------------

.. automodule:: juju.client.runner
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: juju.client
    :members:
    :undoc-members:
    :show-inheritance:
